RoundedProgressBarStyle class

Constructors

RoundedProgressBarStyle({Color? backgroundProgress = backgroundProgressDefault, Color? colorProgress = colorProgressDefault, Color? colorProgressDark = colorProgressDarkDefault, Color? colorBorder = colorBorderDefault, Color? colorBackgroundIcon = colorBorderDefault, double? widthShadow = 6, double? borderWidth = 6})

Properties

backgroundProgress Color?
final
borderWidth double?
final
colorBackgroundIcon Color?
final
colorBorder Color?
final
colorProgress Color?
final
colorProgressDark Color?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widthShadow double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited